@@ -367,7 +367,7 @@ test_fontfuncs_subclassing (void)
 static hb_bool_t
 nominal_glyph_func (hb_font_t *font HB_UNUSED,
 		    void *font_data HB_UNUSED,
-		    hb_codepoint_t unicode,
+		    hb_codepoint_t unicode HB_UNUSED,
 		    hb_codepoint_t *glyph,
 		    void *user_data HB_UNUSED)
 {
@@ -426,6 +426,8 @@ test_fontfuncs_parallels (void)
   /* Just test that calling get_nominal_glyph doesn't infinite-loop. */
   hb_codepoint_t glyph;
   hb_font_get_nominal_glyph (font2, 0x0020u, &glyph);
+
+  hb_font_destroy (font2);
 }
 
 static void
@@ -534,6 +536,11 @@ test_font_properties (void)
   g_assert_cmpint (x_ppem, ==, 17);
   g_assert_cmpint (y_ppem, ==, 19);
 
+  /* Check ptem */
+  g_assert_cmpint (hb_font_get_ptem (font), ==, 0);
+  hb_font_set_ptem (font, 42);
+  g_assert_cmpint (hb_font_get_ptem (font), ==, 42);
+
 
   /* Check immutable */
 
